@@ -47,8 +47,6 @@
 
 extern GstTool *tool;
 
-extern gboolean updating;
-
 static void
 scrolled_window_scroll_bottom (GtkWidget *sw)
 {
@@ -333,8 +331,7 @@ filter_editable (GtkEditable *editable, const gchar *text, gint length,
 		s = g_strconcat (gtk_editable_get_chars (editable, 0, -1), text, NULL);
 		success = is_ip_text_ok (s);
 		g_free (s);
-	}
-	else {
+	} else {
 		while ((i < length) && (string_ok)) {
 			if (is_char_ok (text[i], rules))
 				i++;
@@ -348,14 +345,8 @@ filter_editable (GtkEditable *editable, const gchar *text, gint length,
 			success = FALSE;
 	}
 
-	if (!success) {
-		gdk_beep ();
-	
+	if (!success)
 		gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
-/*		if (s) {
-			gtk_editable_insert_text (editable, s, l, pos);
-			}*/
-	}
 }
 
 /* yeah, I don't like this formatting either */
@@ -417,7 +408,10 @@ init_editable_filters (GstDialog *dialog)
 	};
 
 	for (i = 0; s[i].name; i++)
-		connect_editable_filter (gst_dialog_get_widget (dialog, s[i].name), s[i].rule);
+		g_signal_connect (G_OBJECT (gst_dialog_get_widget (dialog, s[i].name)),
+				  "insert_text",
+				  G_CALLBACK (filter_editable),
+				  GINT_TO_POINTER (s[i].rule));
 
 #warning FIXME
 	return;
@@ -427,7 +421,7 @@ init_editable_filters (GstDialog *dialog)
 		GtkWidget *w = gst_dialog_get_widget (dialog, s1[i].name);
 
 		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (w));
-		g_signal_connect (G_OBJECT (buffer), "insert_text",
+		g_signal_connect (G_OBJECT (buffer), "changed",
 				  G_CALLBACK (filter_editable),
 				  GINT_TO_POINTER (s1[i].rule));
 	}
@@ -523,14 +517,14 @@ activate_directive_cb (GstDirectiveEntry *entry)
 	g_free (entry->report_sign);
 }
 
-void
-on_connection_activate_clicked (GtkWidget *w, gpointer null)
+static void
+on_connection_activate_clicked (GtkWidget *w, GtkTreePath *path, gpointer null)
 {
 	GstConnection *cxn;
 	gchar *sign, *file;
 	gboolean modified = gst_dialog_get_modified (tool->main_dialog);
 
-	cxn = connection_list_get_active ();
+	cxn = connection_list_get_by_path (path);
 	connection_activate (cxn, TRUE);
 
 	file = (cxn->file)? cxn->file: cxn->dev;
@@ -561,14 +555,14 @@ deactivate_directive_cb (GstDirectiveEntry *entry)
 	g_free (entry->report_sign);
 }
 
-void
-on_connection_deactivate_clicked (GtkWidget *w, gpointer null)
+static void
+on_connection_deactivate_clicked (GtkWidget *w, GtkTreePath *path, gpointer null)
 {
 	GstConnection *cxn;
 	gchar *sign, *file;
 	gboolean modified = gst_dialog_get_modified (tool->main_dialog);
 
-	cxn = connection_list_get_active ();
+	cxn = connection_list_get_by_path (path);
 	connection_activate (cxn, FALSE);
 	
 	file = (cxn->file)? cxn->file: cxn->dev;
@@ -596,13 +590,12 @@ void
 on_samba_use_toggled (GtkWidget *w, gpointer null)
 {
 	gboolean active, wins_active, configured, smb_installed;
+	xmlNodePtr root = gst_xml_doc_get_root (tool->config);
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
 	wins_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, "wins_use")));
 	configured = (gboolean) g_object_get_data (G_OBJECT (tool), "tool_configured");
 	smb_installed = (gboolean) g_object_get_data (G_OBJECT (tool), "smbinstalled");
-	xmlNodePtr root = gst_xml_doc_get_root (tool->config);
-
 	
 	if (configured && !smb_installed && active) {
 		GtkWidget *dialog;
@@ -889,56 +882,41 @@ callbacks_tool_not_found_hook (GstTool *tool, GstReportLine *rline, gpointer dat
 /* Connection dialog callbacks */
 
 void
-on_connection_list_clicked (GtkWidget *w, gpointer data)
+on_connection_toggled (GtkWidget *w, gchar *path_str, gpointer data)
 {
-	GtkTreePath *path;
-	GtkTreeViewColumn *column;
-	GtkTreeModel *model;
+	GtkTreeView *treeview = GTK_TREE_VIEW (data);
+	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
+	GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
 	GtkTreeIter iter;
-	GList *column_list;
-	gint ncol;
-	GdkPixbuf *stat_icon;
 	GstConnection *cxn;
-	GtkWidget *dialog;
 	gchar *txt;
+	GtkWidget *dialog;
 
-	cxn = connection_list_get_active ();
-	column_list = gtk_tree_view_get_columns (GTK_TREE_VIEW (w));
-	gtk_tree_view_get_cursor (GTK_TREE_VIEW (w), &path, &column);
-							  
-	ncol = g_list_index (column_list, column) + 1;
+	gtk_tree_model_get_iter (model, &iter, path);
+	cxn = connection_list_get_by_path (path);
 
-	if (ncol == CONNECTION_LIST_COL_STAT_PIX)
-	{
-		model = gtk_tree_view_get_model (GTK_TREE_VIEW (w));
-		gtk_tree_model_get_iter (model, &iter, path);
-		
-		if (!cxn->enabled)
-		{
-			if (cxn->type != GST_CONNECTION_LO) {
-				txt = g_strdup_printf (_("Do you want to enable interface %s?"), cxn->dev);
-				dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, txt);
-				if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
-					on_connection_activate_clicked (w, NULL);
+	if (!cxn->enabled) {
+		if (cxn->type != GST_CONNECTION_LO) {
+			txt = g_strdup_printf (_("Do you want to enable interface %s?"), cxn->dev);
+			dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, txt);
+			if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
+				on_connection_activate_clicked (GTK_WIDGET (treeview), path, NULL);
 
-				gtk_widget_destroy (dialog);
-				g_free (txt);
-			}
+			gtk_widget_destroy (dialog);
+			g_free (txt);
 		}
-		else
-		{
-			if (cxn->type != GST_CONNECTION_LO) {
-				txt = g_strdup_printf (_("Do you want to disable interface %s?"), cxn->dev);
-				dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, txt);
-				if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
-					on_connection_deactivate_clicked (w, NULL);
+	} else {
+		if (cxn->type != GST_CONNECTION_LO) {
+			txt = g_strdup_printf (_("Do you want to disable interface %s?"), cxn->dev);
+			dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, txt);
+			if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
+				on_connection_deactivate_clicked (GTK_WIDGET (treeview), path,  NULL);
 
-				gtk_widget_destroy (dialog);
-				g_free (txt);
-			}
+			gtk_widget_destroy (dialog);
+			g_free (txt);
 		}
 	}
-	g_list_free (column_list);
+	
 	gtk_tree_path_free (path);
 }
 
@@ -1041,6 +1019,22 @@ on_ip_address_focus_out (GtkWidget *widget, GdkEventFocus *event, GstConnection
         return FALSE;
 }
 
+gchar*
+on_volume_format_value (GtkWidget *widget, gdouble value, gpointer data)
+{
+	gchar *string;
+	
+	if (value == 0)
+		string = g_strdup_printf (_("Silent"));
+	else if (value == 1)
+		string = g_strdup_printf (_("Low"));
+	else if (value == 2)
+		string = g_strdup_printf (_("Medium"));
+	else if (value == 3)
+		string = g_strdup_printf (_("Loud"));
+
+	return string;
+}
 
 /* Hosts tab callbacks */
 
@@ -1052,16 +1046,12 @@ gst_hosts_unselect_all (void)
 	GstStatichostUI  *ui;
 	gboolean          valid;
 
-	updating = TRUE;
-
 	ui = (GstStatichostUI *)g_object_get_data (G_OBJECT (tool), STATICHOST_UI_STRING);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->list));
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (ui->list));
 
 	gtk_tree_selection_unselect_all (select);
 	gst_ui_text_view_clear (GTK_TEXT_VIEW (ui->alias));
-
-	updating = FALSE;
 }
 
 static void
@@ -1077,8 +1067,6 @@ gst_hosts_select_row (const gchar *ip_str)
 	if (!ip_str || strlen (ip_str) == 0)
 		return;
 
-	updating = TRUE;
-
 	ui = (GstStatichostUI *)g_object_get_data (G_OBJECT (tool), STATICHOST_UI_STRING);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->list));
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (ui->list));
@@ -1090,7 +1078,6 @@ gst_hosts_select_row (const gchar *ip_str)
 		if (!strcmp (buf, ip_str)) {
 			gtk_tree_selection_select_iter (select, &iter);
 
-			updating = FALSE;
 			g_free (buf);
 
 			return;
@@ -1099,8 +1086,6 @@ gst_hosts_select_row (const gchar *ip_str)
 		g_free (buf);
 		valid = gtk_tree_model_iter_next (model, &iter);
 	}
-
-	updating = FALSE;
 }	
 
 static void
@@ -1110,10 +1095,8 @@ gst_hosts_clear_entries (void)
 
 	ui = (GstStatichostUI *)g_object_get_data (G_OBJECT (tool), STATICHOST_UI_STRING);
 
-	updating = TRUE;
 	gtk_editable_delete_text (GTK_EDITABLE (ui->ip), 0, -1);
 	gst_ui_text_view_clear (GTK_TEXT_VIEW (ui->alias));
-	updating = FALSE;
 }
 
 static char *
@@ -1137,9 +1120,6 @@ on_hosts_ip_changed (GtkEditable *ip, gpointer not_used)
 {
 	const gchar *ip_str;
 
-	if (updating)
-		return;
-
 	gst_hosts_update_sensitivity ();
 
 	/* Get the texts */
@@ -1151,6 +1131,7 @@ on_hosts_ip_changed (GtkEditable *ip, gpointer not_used)
 void
 on_hosts_alias_changed (GtkTextBuffer *w, gpointer not_used)
 {
+	const gchar *ip_str;
 	char *s;
 	GstStatichostUI *ui;
 	GtkTreeModel    *model;
@@ -1160,22 +1141,25 @@ on_hosts_alias_changed (GtkTextBuffer *w, gpointer not_used)
 	if (!gst_tool_get_access (tool))
 		return;
 
-	if (updating)
-		return;
-
 	ui = (GstStatichostUI *)g_object_get_data (G_OBJECT (tool), STATICHOST_UI_STRING);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->list));
+	ip_str = gtk_editable_get_chars (GTK_EDITABLE (ui->ip), 0, -1);
 
-	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (ui->list));
-	if (gtk_tree_selection_get_selected (select, &model, &iter)) {
-		s = fixup_text_list (ui->alias);
+	if (gst_hosts_ip_is_in_list (ip_str)) {
+		select = gtk_tree_view_get_selection (GTK_TREE_VIEW (ui->list));
+		if (gtk_tree_selection_get_selected (select, &model, &iter)) {
+			s = fixup_text_list (ui->alias);
+			
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+					    STATICHOST_LIST_COL_IP, gtk_editable_get_chars (GTK_EDITABLE (ui->ip), 0, -1),
+					    STATICHOST_LIST_COL_ALIAS, s,
+					    -1);
 
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    STATICHOST_LIST_COL_IP, gtk_editable_get_chars (GTK_EDITABLE (ui->ip), 0, -1),
-				    STATICHOST_LIST_COL_ALIAS, s,
-				    -1);
+			gst_dialog_modify (tool->main_dialog);
+			g_free (s);
 
-		g_free (s);
+
+		}
 	}
 }
 
