@@ -42,15 +42,15 @@ struct _GstNetworkInterfaceDescription {
 };
 
 static GstNetworkInterfaceDescription gst_iface_desc [] = {
-	{ N_("Other type"),                   GST_CONNECTION_OTHER,   "network.png",     "other_type", NULL },
-	{ N_("Ethernet LAN card"),            GST_CONNECTION_ETH,     "16_ethernet.xpm", "eth",        NULL },
-	{ N_("WaveLAN wireless LAN"),         GST_CONNECTION_WLAN,   "wavelan-16.png",  "wvlan",      NULL },
-	{ N_("PPP: modem or transfer cable"), GST_CONNECTION_PPP,     "16_ppp.xpm",      "ppp",        NULL },
-	{ N_("Parallel line"),                GST_CONNECTION_PLIP,    "16_plip.xpm",     "plip",       NULL },
-	{ N_("Infrared LAN"),                 GST_CONNECTION_IRLAN,   "irda-16.png",     "irlan",      NULL },
-	{ N_("Loopback: virtual interface"),  GST_CONNECTION_LO,      "16_loopback.xpm", "lo",         NULL },
-	{ N_("Unknown type"),                 GST_CONNECTION_UNKNOWN, "network.png",     NULL,         NULL },
-	{ NULL,                               GST_CONNECTION_UNKNOWN, NULL,              NULL,         NULL  }
+	{ N_("Other type"),              GST_CONNECTION_OTHER,   "network.png",     "other_type", NULL },
+	{ N_("Ethernet LAN card"),       GST_CONNECTION_ETH,     "16_ethernet.xpm", "eth",        NULL },
+	{ N_("WaveLAN wireless LAN"),    GST_CONNECTION_WLAN,    "wavelan-16.png",  "wvlan",      NULL },
+	{ N_("Modem or transfer cable"), GST_CONNECTION_PPP,     "16_ppp.xpm",      "ppp",        NULL },
+	{ N_("Parallel line"),           GST_CONNECTION_PLIP,    "16_plip.xpm",     "plip",       NULL },
+	{ N_("Infrared LAN"),            GST_CONNECTION_IRLAN,   "irda-16.png",     "irlan",      NULL },
+	{ N_("Loopback interface"),      GST_CONNECTION_LO,      "16_loopback.xpm", "lo",         NULL },
+	{ N_("Unknown interface type"),  GST_CONNECTION_UNKNOWN, "network.png",     NULL,         NULL },
+	{ NULL,                          GST_CONNECTION_UNKNOWN,  NULL,             NULL,         NULL }
 };
 
 #define W(s) my_get_widget (cxn->xml, (s))
@@ -431,20 +431,24 @@ connection_get_dev_pixbuf (GstConnection *cxn)
 	return NULL;
 }
 
-static GdkPixbuf *
-connection_get_stat_pixbuf (GstConnection *cxn)
+static gboolean
+connection_get_stat (GstConnection *cxn)
 {
-	static GdkPixbuf *active;
-	static GdkPixbuf *inactive;
+	return cxn->enabled;
+}
+
+static const gchar*
+connection_get_dev_type (GstConnection *cxn)
+{
+	gint i;
 
 	g_return_val_if_fail (cxn != NULL, NULL);
 
-	if (active == NULL)
-		active = load_pixbuf ("gnome-light-on.png");
-	if (inactive == NULL)
-		inactive = load_pixbuf ("gnome-light-off.png");
+	for (i = 0; gst_iface_desc[i].description != NULL; i++)
+		if (gst_iface_desc[i].type == cxn->type)
+			return _(gst_iface_desc[i].description);
 
-	return cxn->enabled ? active : inactive;
+	return NULL;
 }
 
 static GtkTreeModel *
@@ -455,7 +459,8 @@ connection_list_model_new (void)
 	store = gtk_list_store_new (CONNECTION_LIST_COL_LAST,
 				    GDK_TYPE_PIXBUF,
 				    G_TYPE_STRING,
-				    GDK_TYPE_PIXBUF,
+				    G_TYPE_STRING,
+				    G_TYPE_BOOLEAN,
 				    G_TYPE_STRING,
 				    G_TYPE_POINTER);
 	return GTK_TREE_MODEL (store);
@@ -468,9 +473,13 @@ connection_list_add_columns (GtkTreeView *treeview)
 	GtkTreeViewColumn *col;
 	GtkTreeModel      *model = gtk_tree_view_get_model (treeview);
 
-	/* Device */
+	/* Device type */
 	col = gtk_tree_view_column_new ();
-	gtk_tree_view_column_set_title  (col, _("Device"));
+
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_sort_column_id (col, 1);
+	
+	gtk_tree_view_column_set_title (col, _("Type"));
 
 	pixbuf_renderer = gtk_cell_renderer_pixbuf_new ();
 
@@ -479,27 +488,40 @@ connection_list_add_columns (GtkTreeView *treeview)
 
 	text_renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (col, text_renderer, TRUE);
-	gtk_tree_view_column_add_attribute (col, text_renderer, "text", CONNECTION_LIST_COL_DEVICE);
+	gtk_tree_view_column_add_attribute (col, text_renderer, "text", CONNECTION_LIST_COL_DEV_TYPE);
+
+	gtk_tree_view_append_column (treeview, col);
+	
+	/* Device */
+	text_renderer = gtk_cell_renderer_text_new ();
+
+	col = gtk_tree_view_column_new_with_attributes (_("Device"), text_renderer,
+							"text", CONNECTION_LIST_COL_DEVICE,
+							NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_sort_column_id (col, 2);
 
 	gtk_tree_view_append_column (treeview, col);
 
 	/* Status */
-	col = gtk_tree_view_column_new ();
-	gtk_tree_view_column_set_title  (col, _("Status"));
-
-	pixbuf_renderer = gtk_cell_renderer_pixbuf_new ();
-
-	g_object_set (G_OBJECT (pixbuf_renderer), "xalign", 0.5, NULL);
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW(treeview), -1, _("Status"), 
-	      pixbuf_renderer,"pixbuf", CONNECTION_LIST_COL_STAT_PIX, NULL);
+	pixbuf_renderer = gtk_cell_renderer_toggle_new ();
+	g_signal_connect (G_OBJECT (pixbuf_renderer), "toggled", 
+			  G_CALLBACK (on_connection_toggled), treeview);
+	col = gtk_tree_view_column_new_with_attributes (_("Status"), pixbuf_renderer,
+							"active", CONNECTION_LIST_COL_STAT,
+							NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_clickable (col, TRUE);
+	gtk_tree_view_append_column (treeview, col);
 	                                                                    
 	/* Description */
 	text_renderer = gtk_cell_renderer_text_new ();
-	col = gtk_tree_view_column_new_with_attributes (_("Description"),
-							text_renderer,
-							"text",
-							CONNECTION_LIST_COL_DESCR,
+	col = gtk_tree_view_column_new_with_attributes (_("Description"), text_renderer,
+							"text", CONNECTION_LIST_COL_DESCR,
 							NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_sort_column_id (col, 4);
+
 	gtk_tree_view_append_column (treeview, col);
 }
 
@@ -541,6 +563,20 @@ connection_list_get_active (void)
 	return cxn;
 }
 
+GstConnection*
+connection_list_get_by_path (GtkTreePath *path)
+{
+	GstConnectionUI  *ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
+	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->list));
+	GtkTreeIter iter;
+	GstConnection    *cxn = NULL;
+
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter, CONNECTION_LIST_COL_DATA, &cxn, -1);
+
+	return cxn;
+}
+
 static gboolean
 connection_iter (GstConnection *cxn, GtkTreeIter *iter)
 {
@@ -558,7 +594,7 @@ connection_iter (GstConnection *cxn, GtkTreeIter *iter)
 	while (valid) {
 		gtk_tree_model_get (model, iter, CONNECTION_LIST_COL_DATA, &c, -1);
 
-		if (!strcmp (cxn->dev, c->dev))
+		if (!strcmp (cxn->file, c->file))
 			return TRUE;
 
 		valid = gtk_tree_model_iter_next (model, iter);
@@ -567,6 +603,20 @@ connection_iter (GstConnection *cxn, GtkTreeIter *iter)
 	return FALSE;
 }
 
+void
+connection_list_clear (GstTool *tool)
+{
+	GstConnectionUI *ui;
+	GtkTreeModel    *model;
+
+	g_return_if_fail (tool != NULL);
+
+	ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->list));
+
+	gtk_list_store_clear (GTK_LIST_STORE (model));
+}
+
 GtkWidget *
 connection_list_new (GstTool *tool)
 {
@@ -580,9 +630,6 @@ connection_list_new (GstTool *tool)
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), model);
 	g_object_unref (G_OBJECT (model));
 
-	g_signal_connect (G_OBJECT (treeview), "cursor-changed", 
-	      G_CALLBACK (on_connection_list_clicked), NULL);
-
 	connection_list_add_columns (GTK_TREE_VIEW (treeview));
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
@@ -615,8 +662,9 @@ connection_list_append (GstConnection *cxn)
 
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 			    CONNECTION_LIST_COL_DEV_PIX,  connection_get_dev_pixbuf (cxn),
+			    CONNECTION_LIST_COL_DEV_TYPE, connection_get_dev_type (cxn),
 			    CONNECTION_LIST_COL_DEVICE,   cxn->dev,
-			    CONNECTION_LIST_COL_STAT_PIX, connection_get_stat_pixbuf (cxn),
+			    CONNECTION_LIST_COL_STAT,     connection_get_stat (cxn),
 			    CONNECTION_LIST_COL_DESCR,    cxn->name,
 			    CONNECTION_LIST_COL_DATA,     cxn,
 			    -1);
@@ -1177,6 +1225,7 @@ connection_get_ppp_from_node (xmlNode *node, GstConnection *cxn)
 	if (cxn->wvsection) {
 		cxn->serial_port = connection_get_serial_port_from_node (node->parent, cxn->wvsection);
 		cxn->phone_number = connection_xml_wvsection_get_str (node->parent, cxn->wvsection, "phone");
+		cxn->external_line = connection_xml_wvsection_get_str (node->parent, cxn->wvsection, "external_line");
 		cxn->login = connection_xml_wvsection_get_str (node->parent, cxn->wvsection, "login");
 		cxn->password = connection_xml_wvsection_get_str (node->parent, cxn->wvsection, "password");
 		cxn->stupid = connection_xml_wvsection_get_boolean (node->parent, cxn->wvsection, "stupid");
@@ -1187,6 +1236,7 @@ connection_get_ppp_from_node (xmlNode *node, GstConnection *cxn)
 		connection_xml_save_str_to_node (cxn->node, "wvsection", cxn->wvsection);
 
 		cxn->phone_number = gst_xml_get_child_content (node, "phone_number");
+		cxn->external_line = gst_xml_get_child_content (node, "external_line");
 		cxn->login = gst_xml_get_child_content (node, "login");
 		cxn->password = gst_xml_get_child_content (node, "password");
 		cxn->stupid = FALSE;
@@ -1386,6 +1436,7 @@ connection_free (GstConnection *cxn)
 	g_free (cxn->session_id);
 
 	g_free (cxn->phone_number);
+	g_free (cxn->external_line);
 	g_free (cxn->login);
 	g_free (cxn->password);
 	g_free (cxn->serial_port);
@@ -1519,6 +1570,7 @@ static void
 empty_ppp (GstConnection *cxn)
 {
 	GET_STR ("ppp_", phone_number);
+	GET_STR ("ppp_", external_line);
 	GET_STR ("ppp_", login);
 	GET_STR ("ppp_", password);
 	GET_BOOL ("ppp_", persist);
@@ -1729,6 +1781,7 @@ static void
 fill_ppp (GstConnection *cxn)
 {
 	SET_STR ("ppp_", phone_number);
+	SET_STR ("ppp_", external_line);
 	SET_STR ("ppp_", login);
 	SET_STR ("ppp_", password);
 	SET_BOOL ("ppp_", persist);
@@ -1782,6 +1835,7 @@ hookup_callbacks (GstConnection *cxn)
 		{ "on_ppp_autodetect_modem_clicked", on_ppp_autodetect_modem_clicked },
 		{ "on_ip_address_focus_out", on_ip_address_focus_out },
 		{ "on_ip_netmask_focus_out", on_ip_address_focus_out },
+		{ "on_volume_format_value", on_volume_format_value },
 		{ NULL }
 	};
 
@@ -1806,7 +1860,9 @@ hookup_callbacks (GstConnection *cxn)
 		glade_xml_signal_connect_data (cxn->xml, signals[i].hname,
 					       signals[i].signalfunc, cxn);
 	for (i = 0; s[i].name; i++)
-		connect_editable_filter (W (s[i].name), s[i].rule);
+		g_signal_connect (G_OBJECT (W (s[i].name)), "insert_text",
+				  G_CALLBACK (filter_editable),
+				  GINT_TO_POINTER (s[i].rule));
 }
 
 
@@ -2003,6 +2059,7 @@ connection_save_to_node (GstConnection *cxn, xmlNode *root)
 		connection_xml_save_str_to_node (node, "wvsection", cxn->wvsection);
 		
 		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "phone", cxn->phone_number);
+		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "external_line", cxn->external_line);
 		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "login", cxn->login);
 		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "password", cxn->password);
 		connection_xml_wvsection_save_boolean_to_node (root, cxn->wvsection, "stupid", cxn->stupid);
